add_rconnect_file: Add an app.R at the root of your package to deploy on RStudio Connect
Description
Add an app.R at the root of your package to deploy on RStudio Connect
Usage
add_rconnect_file(pkg = ".")
Arguments
pkg
Path to the root of the package. Default is `"."`.