{golem} working directoryMany {golem} functions rely on a specific working directory,
most of the time the root of the package. This working directory
is set by set_golem_options or the first time you create a file.
It default to ".", the current directory when starting a golem.
You can use these two functions if you need to manipulate this
directory.
get_golem_wd()set_golem_wd(path, talkative = TRUE)
The path to set the golem woking directory.
Note that it will be passed to normalizePath.
Should the function print where the new path is defined?
The path to the working directory.