This function calls rstudioapi::documentSaveAll(),
roxygen2::roxygenise() and pkgload::load_all().
Usage
document_and_reload(
golem_wd = get_golem_wd(),
roclets = NULL,
load_code = NULL,
clean = FALSE,
export_all = FALSE,
helpers = FALSE,
attach_testthat = FALSE,
...,
pkg
)Arguments
- golem_wd
Path to the root of the package. Default is
get_golem_wd().- roclets
Character vector of roclets to use.
The default,
NULL, uses the roxygenrocletsoption, which defaults toc("collate", "namespace", "rd"). This will update (if needed) theCollatefield withupdate_collate(), produce theNAMESPACEfile withnamespace_roclet(), and produce the Rd files withrd_roclet().(Note that
update_collate()is not technically a roclet but is still controlled with this argument for historical reasons.)- load_code
A function used to load all the R code in the package directory. The default,
NULL, uses the strategy defined by theloadroxygen option, which defaults toload_pkgload(). See load for more details.- clean
If
TRUE, roxygen will delete all files previously created by roxygen before running each roclet.- export_all
If
TRUE(the default), export all objects. IfFALSE, export only the objects that are listed as exports in the NAMESPACE file.- helpers
if
TRUEloads testthat test helpers.- attach_testthat
If
TRUE, attach testthat to the search path, which more closely mimics the environment within test files.- ...
Other arguments passed to
pkgload::load_all()- pkg
Deprecated, please use golem_wd instead