Set the golem_wd value (the working directory of the current golem
package) inside the golem-config.yml file.
Arguments
- new_golem_wd, current_golem_wd
New & current directory, to be used in
set_golem_wd().- talkative
Should the messages be printed to the console?
- golem_wd
This argument has been replaced by
new_golem_wdand is kept here for backward compatibility. Providing a value to this argument has no effect: the value is silently ignored, andnew_golem_wdis used instead.- pkg
This argument has been replaced by
current_golem_wdand is kept here for backward compatibility. Providing a value to this argument has no effect: the value is silently ignored, andcurrent_golem_wdis used instead.