Skip to contents

Add recommended elements

Usage

use_recommended_tests(
  golem_wd = get_golem_wd(),
  spellcheck = TRUE,
  vignettes = TRUE,
  lang = "en-US",
  error = FALSE,
  pkg
)

Arguments

golem_wd

Path to the root of the package. Default is get_golem_wd().

spellcheck

Whether or not to use a spellcheck test.

vignettes

Logical, TRUE to spell check all rmd and rnw files in the vignettes/ folder.

lang

Preferred spelling language. Usually either "en-US" or "en-GB".

error

Logical, indicating whether the unit test should fail if spelling errors are found. Defaults to FALSE, which does not error, but prints potential spelling errors

pkg

Deprecated, please use golem_wd instead

Value

Used for side-effects.